@@ -1,13 +1,13 @@
 use strictures;
 
 package WebService::GoogleAPI::Client;
-$WebService::GoogleAPI::Client::VERSION = '0.11';
+$WebService::GoogleAPI::Client::VERSION = '0.12';
 
 # ABSTRACT: Google API Services Client.
 
 
 use Data::Dumper;
-use Moose;
+use Moo;
 use WebService::GoogleAPI::Client::UserAgent;
 use WebService::GoogleAPI::Client::Discovery;
 use Carp;
@@ -294,6 +294,14 @@ sub has_scope_to_access_api_endpoint
 
 
 
+#=head2 MANUAL API REQUEST CONSTRUCTION
+#    ## Completely manually constructed API End-Point Request to obtain Perl Data Structure converted from JSON response.
+#    my $res = $gapi_client->api_query(
+#      method => 'get',
+#      path => 'https://www.googleapis.com/calendar/users/me/calendarList',
+#    )->json;
+#
+
 1;
 
 __END__
@@ -308,34 +316,51 @@ WebService::GoogleAPI::Client - Google API Services Client.
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
 Access Google API Services Version 1 using an OAUTH2 User Agent
 
-    ## use goauth CLI helper to create the OATH credentials file ( see perldoc goauth )
-
     use WebService::GoogleAPI::Client;
-    use Data::Dumper;
 
-    my $gapi = WebService::GoogleAPI::Client->new(debug => 0); # my $gapi = WebService::GoogleAPI::Client->new(access_token => '');
-    my $user = 'peter@pscott.com.au'; # full gmail or G-Suite email
+    ## assumes gapi.json configuration in working directory with scoped project and user authorization
+    
+    my $gapi_client = WebService::GoogleAPI::Client->new( debug => 1, gapi_json => './gapi.json', user=> 'peter@pscott.com.au' );
 
-    $gapi->auth_storage->setup({type => 'jsonfile', path => './gapi.json' }); # by default
+=head2 AUTOMATIC API REQUEST CONSTRUCTION  - SEND EMAL
 
-    $gapi->user($user);       ## allows to select user configuration by google auth'd email address
-    $gapi->do_autorefresh(1); ## refresh auth token with refresh token if auth session has expired
+    ## using dotted API Endpoint id to invoke helper validation and default value interpolations etc to send email to self
+    use Email::Simple;    ## RFC2822 formatted messages
+    use MIME::Base64;
+    my $my_email_address = 'peter@shotgundriver.com'
 
-=head2 OAUTH CREDENTIALS FILE TO ACCESS SERVCICES
 
-TODO
+    my $raw_email_payload = encode_base64( Email::Simple->create( header => [To => $my_email_address, 
+                                                                             From => $my_email_address, 
+                                                                             Subject =>"Test email from '$my_email_address' ",], 
+                                                                             body => "This is the body of email to '$my_email_address'", 
+                                                                )->as_string 
+                                        );
 
-=head2 BUILD
+    $gapi_client->api_query( 
+                            api_endpoint_id => 'gmail.users.messages.send',
+                            options    => { raw => $raw_email_payload },
+                        );
+
+=head2 MANUAL API REQUEST CONSTRUCTION - GET CALENDAR LIST
+
+    ## Completely manually constructed API End-Point Request to obtain Perl Data Structure converted from JSON response.
+    my $res = $gapi_client->api_query(
+      method => 'get',
+      path => 'https://www.googleapis.com/calendar/users/me/calendarList',
+    )->json;
+
+=head2 C<new>
 
 WebService::GoogleAPI::Client->new( user => 'useremail@sdf.com', gapi_json => '/fullpath/gapi.json' );
 
-=head2 api_query
+=head2 C<api_query>
 
 query Google API with option to validate request before submitting
 
@@ -422,36 +447,7 @@ WHen called in a scalar context returns the list as a comma joined string.
 
 DELEGATED FROM WebService::GoogleAPI::Client::Discovery
 
-=head1 FUNCTIONAL CLASS PROPERTIES
-
-=head2 ua
-
-Is a WebService::GoogleAPI::Client::UserAgent
-
-=head3 DELEGATE METHOD 
-
-=head1 METHODS DELEGATED TO PROPERTY CLASS INSTANCES
-
-=head2 C<access_token>
-ua handles: 
-  access_token 
-  auth_storage  
-  do_autorefresh 
-  get_scopes_as_array 
-  user
-
-discovery handles:
-  discover_all  
-  extract_method_discovery_detail_from_api_spec 
-  get_api_discovery_for_api_id
-  get_method_meta  
-
-=head1 KEY FEATURES
-
-Aim is to streamline endpoint access without forcing an additional opinionated abstraction layer that imposes unecessary
-congnitive load. 
-Users of the module should be able to access all Google Services and either use helper features or fully construct
-requests in a way that is as portable to alternative approaches as possible.
+=head1 FEATURES
 
 =over 1
 
@@ -467,36 +463,6 @@ requests in a way that is as portable to alternative approaches as possible.
 
 =back
 
-=head2 TODO: 
-
-=over 1
-
-=item Refactor AuthStorage and Credentials modules - include capability to handle service accounts credentials which are not currently supported. See https://gist.github.com/gsainio/6322375
-
-=item standardise terminology in documentation and code
-
-=item include POD for delegated methods 
-
-=item basic CLI to query API Discovery data ( Potentially with OPEN/Swagger Output option ) potenitlaly evolving to something similar to gcloud
-
-=back
-
-=head1 SEE ALSO
-
-=over 1
-
-=item * L<Google Cloud Client Libraries https://cloud.google.com/apis/docs/cloud-client-libraries>
-
-=item * L<Google Cloud Blog https://www.blog.google/products/google-cloud/>
-
-=item * L<Moo::Google> - The original code base later forked into L<WebService::Google::Client> by Steve Dondley. Some shadows of the original design remain
-
-=item * L<Google Swagger API https://github.com/APIs-guru/google-discovery-to-swagger> 
-
-=item * L<OAuth2::Client::Google> - Perl 6 OAuth2 Client 
-
-=back
-
 =head1 AUTHOR
 
 Peter Scott <localshop@cpan.org>
